# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-04-22 00:28
from __future__ import unicode_literals

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0016_auto_20190111_1554'),
    ]

    operations = [
        migrations.CreateModel(
            name='RegCode',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('reg_code', models.CharField(max_length=50, verbose_name=b'\xe6\xb3\xa8\xe5\x86\x8c\xe5\x8d\xa1\xe5\xaf\x86')),
                ('reg_name', models.CharField(max_length=180, verbose_name=b'\xe6\xb3\xa8\xe5\x86\x8c\xe5\x8d\xa1\xe5\x8f\xb7')),
                ('created_at', models.DateTimeField(default=django.utils.timezone.now)),
            ],
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-06-22 08:03
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('bee_django_crm', '0003_auto_20180608_1917'),
    ]

    operations = [
        migrations.AddField(
            model_name='preuser',
            name='referral_user1',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='bee_crm_referral_user1', to=settings.AUTH_USER_MODEL, verbose_name=b'\xe6\x8e\xa8\xe8\x8d\x90\xe4\xba\xba'),
        ),
        migrations.AddField(
            model_name='preuser',
            name='referral_user2',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='bee_crm_referral_user2', to=settings.AUTH_USER_MODEL, verbose_name=b'\xe6\x8e\xa5\xe5\xbc\x95\xe4\xba\xba'),
        ),
        migrations.AlterField(
            model_name='preuser',
            name='referral_user',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='bee_crm_referral_user', to=settings.AUTH_USER_MODEL, verbose_name=b'\xe5\x8e\x9f\xe6\x8e\xa8\xe8\x8d\x90\xe4\xba\xba'),
        ),
    ]



# -*- coding:utf-8 -*-
__author__ = 'zhangyue'

from django import forms

from .validators import jpg_validator, poster_image_size_validator
from .models import PreUser,RegCode, ApplicationQuestion, ApplicationOption, Source, \
    PreUserTrack, Contract, PreUserContract, Poster, PreUserFee
from .models import PREUSER_GENDER_CHOICES, PREUSER_GRADE_CHOICES, PREUSER_LEVEL_CHOICES, CONTRACT_PERIOD_CHOICES
from .utils import get_referral_user_name_with_user, get_preuser_source


# 管理者添加的preuser表
class PreuserCreateForm(forms.ModelForm):
    name = forms.CharField(label='姓名',
                           widget=forms.TextInput(attrs={'placeholder': '姓名 (必填)'}))
    mobile = forms.CharField(label='电话', widget=forms.TextInput(attrs={'placeholder': '电话 (必填)'}),
                             error_messages={'unique': u'该电话已存在'})
    gender = forms.ChoiceField(choices=PREUSER_GENDER_CHOICES, label='性别', widget=forms.RadioSelect, required=True)
    wx = forms.CharField(label='微信号', widget=forms.TextInput(attrs={'placeholder': '微信号'}), required=False)

    class Meta:
        model = PreUser
        fields = ['name', "mobile", "gender", "province", "city", "wx"]

# 会员根据课程卡密，自己注册
class PreuserCouponCreateForm(PreuserCreateForm):
    code = forms.CharField(label='课程卡号',widget=forms.TextInput(attrs={'placeholder': '课程卡号 (必填)'}))
    password = forms.CharField(label='课程密码',widget=forms.TextInput(attrs={'placeholder': '课程密码 (必填)'}))
    class Meta:
        model = PreUser
        fields = ['code','password','name', "mobile", "gender", "province", "city", "wx"]


class RegCodeCheckForm(forms.ModelForm):
    reg_name = forms.CharField(label='课程卡号',widget=forms.TextInput(attrs={'placeholder': '课程卡号 (必填)'}),required=False)
    reg_code = forms.CharField(label='课程密码',widget=forms.TextInput(attrs={'placeholder': '课程密码'}),required=False)
    class Meta:
        model = RegCode
        fields = ['reg_name','reg_code']


# 管理者更新的preuser表
class PreuserUpdateAdminForm(PreuserCreateForm):
    grade = forms.ChoiceField(choices=PREUSER_GRADE_CHOICES, label='意向', required=False)

    # source = forms.ModelChoiceField(queryset=Source.objects.filter(is_show=True), label='来源', required=False)

    referral_user_id1 = forms.CharField(required=False,
                                        widget=forms.TextInput(attrs={'onchange': 'get_referral_user_name(1);'}),
                                        help_text="", label="推荐人id")
    referral_user_id2 = forms.CharField(required=False,
                                        widget=forms.TextInput(attrs={'onchange': 'get_referral_user_name(2);'}),
                                        help_text="", label="接引人id")

    def __init__(self, preuser, *args, **kwargs):
        super(PreuserUpdateAdminForm, self).__init__(*args, **kwargs)
        #

        referral_user_name1 = u"无"
        referral_user_name2 = u"无"
        if self.instance.referral_user1_id:
            self.initial['referral_user_id1'] = self.instance.referral_user1_id
            referral_user_name1 = get_referral_user_name_with_user(self.instance.referral_user1.id)
        if self.instance.referral_user2_id:
            self.initial['referral_user_id2'] = self.instance.referral_user2_id
            referral_user_name2 = get_referral_user_name_with_user(self.instance.referral_user2.id)
        self.fields[
            'referral_user_id1'].help_text = u"(推荐人：<text id='referral_user_name1'>" + referral_user_name1 + u"</text>)"
        self.fields[
            'referral_user_id2'].help_text = u"(接引人：<text id='referral_user_name2'>" + referral_user_name2 + u"</text>)"
        # try:
        # from itertools import chain
        # source = get_preuser_source(preuser.id)
        # self.source_queryset = chain(source_queryset, [source])
        # self.initial['source'] = "aa"
        # except Exception as e:
        #     print(e)
        # print(self.source_queryset)
        # for i in self.source_queryset:
        #     print(i.name)
        from django.db.models import Q
        source_queryset = Source.objects.filter(Q(is_show=True) | Q(preuser__source=preuser.source)).distinct()
        self.fields["source"] = forms.ModelChoiceField(queryset=source_queryset, label='来源', required=False)

    class Meta:
        model = PreUser
        fields = ['name', "mobile", "gender", "grade", "wx", "birthday", "province", "city", "address", 'source',
                  # fields = ['name', "mobile", "gender", "grade", "wx", "birthday", "province", "city", "address",
                  "referral_user_id1", "referral_user_id2", "email", "job", "hobby", "married", "children", "job_info",
                  "family"]


# 用户自己更新的preuser表
class PreuserUpdateUserForm(PreuserCreateForm):
    birthday = forms.DateField(label='出生日期', help_text='格式：2017-01-01', error_messages={'invalid': u'日期格式不正确'})
    address = forms.CharField(widget=forms.Textarea, label='地址', required=True)

    class Meta:
        model = PreUser
        fields = ['name', "mobile", "gender", "wx", "birthday", "province", "city", "address", ]


class PreuserSearchForm(forms.ModelForm):
    grade_choices = ((-1, '全部'), (0, '无'), (1, '弱'), (2, '强'))
    level = forms.ChoiceField(choices=PREUSER_LEVEL_CHOICES, label='级别', required=False)
    grade = forms.ChoiceField(choices=grade_choices, label='意愿', required=False)
    name = forms.CharField(label='姓名', required=False)
    mobile = forms.CharField(label='电话', required=False)
    contract = forms.ModelChoiceField(queryset=Contract.objects.all(), label='合同', required=False)
    source_name = forms.CharField(label='报名来源', required=False)
    referral_name1 = forms.CharField(required=False, label="推荐人姓名")

    class Meta:
        model = PreUser
        fields = ['level', 'grade', 'name', "mobile", "contract", 'source_name', 'referral_name1', "province", "city", ]


# ===source===
class SourceForm(forms.ModelForm):
    class Meta:
        model = Source
        fields = ['name', 'reg_name', 'is_show', 'is_poster']


class SourceUpdateForm(forms.ModelForm):
    class Meta:
        model = Source
        fields = ['reg_name', 'is_show', 'is_poster']


class SourceSearchForm(forms.Form):
    name = forms.CharField(label='渠道名', required=False)


# ===preuser track===
class PreuserTrackForm(forms.ModelForm):
    class Meta:
        model = PreUserTrack
        fields = ['tracked_at', 'info']


# ===application question======
class ApplicationQuestionCreateForm(forms.ModelForm):
    class Meta:
        model = ApplicationQuestion
        fields = ['name', "order_by", "input_type", 'is_required']


class ApplicationOptionCreateForm(forms.ModelForm):
    class Meta:
        model = ApplicationOption
        fields = ['name', "order_by"]


# =====contract======
class ContractForm(forms.ModelForm):
    period = forms.ChoiceField(choices=CONTRACT_PERIOD_CHOICES, label="周期")

    class Meta:
        model = Contract
        fields = ['name', "period", "duration", "price"]

    # def validate_unique(self):
    #     exclude = self._get_validation_exclusions()
    #     # exclude.remove('level') # allow checking against the missing attribute
    #
    #     try:
    #         self.instance.validate_unique(exclude=exclude)
    #     except forms.ValidationError, e:
    #         self._update_errors(e.message_dict)

    def clean(self):
        period = self.cleaned_data['period']
        duration = self.cleaned_data['duration']
        if not period == "9999":
            if not duration:
                raise forms.ValidationError(u"请填写时长")
        return self.cleaned_data


class ContractUpdateAgreementForm(forms.ModelForm):
    class Meta:
        model = Contract
        fields = ["agreement"]


# ===== preuser contract======
class PreuserContractForm(forms.ModelForm):
    study_at = forms.DateTimeField(label=u'开课日期', required=True)

    class Meta:
        model = PreUserContract
        fields = ['contract', "price", "study_at", "info"]


class PreuserContractAgreementForm(forms.ModelForm):
    is_user_agree = forms.BooleanField(required=True, label=u'同意以上协议')

    class Meta:
        model = PreUserContract
        fields = ['is_user_agree']


class PreuserContractSearchForm(forms.Form):
    name = forms.CharField(label='姓名', required=False)
    contract = forms.ModelChoiceField(queryset=Contract.objects.all(), label='合同', required=False)


class PreuserFeeForm(forms.ModelForm):
    class Meta:
        model = PreUserFee
        fields = ["pay_status", "price", "paid_at", "info"]


class PreuserFeeSearchForm(forms.Form):
    preuser_pay_status_choices = ((-1, '全部'), (1, "全款缴清"), (2, "分期中"))
    is_checked_choices = ((-1, '全部'), (1, "已审核"), (0, "未审核"))

    is_checked = forms.ChoiceField(choices=is_checked_choices, label='审核', required=False)
    preuser_pay_status = forms.ChoiceField(choices=preuser_pay_status_choices, label='缴费人', required=False)
    pay_start = forms.CharField(label='缴费开始日期', required=False)
    pay_end = forms.CharField(label='缴费结束日期', required=False)


# ====== poster ======

class PosterCreateForm(forms.ModelForm):
    photo = forms.ImageField(validators=[jpg_validator, poster_image_size_validator])

    class Meta:
        model = Poster
        fields = ["photo"]


class PosterUpdateForm(forms.ModelForm):
    qrcode_width = forms.IntegerField(min_value=1, label='二维码宽度')
    qrcode_height = forms.IntegerField(min_value=1, label='二维码高度')

    class Meta:
        model = Poster
        fields = ["qrcode_width", "qrcode_height", "qrcode_pos_x", "qrcode_pos_y", "qrcode_color", "is_show"]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-08-22 09:36
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('bee_django_crm', '0005_auto_20180708_1503'),
    ]

    operations = [
        migrations.CreateModel(
            name='PreUserFee',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('price', models.FloatField(verbose_name=b'\xe5\xae\x9e\xe6\x94\xb6\xe9\x87\x91\xe9\xa2\x9d')),
                ('paid_at', models.DateTimeField(verbose_name=b'\xe7\xbc\xb4\xe8\xb4\xb9\xe6\x97\xa5\xe6\x9c\x9f')),
                ('study_at', models.DateTimeField(blank=True, null=True, verbose_name=b'\xe5\xbc\x80\xe8\xaf\xbe\xe6\x97\xa5\xe6\x9c\x9f')),
                ('pay_status', models.IntegerField(choices=[(1, b'\xe5\x85\xa8\xe6\xac\xbe'), (2, b'\xe5\x88\x86\xe6\x9c\x9f\xe5\xa4\xb4\xe6\xac\xbe'), (3, b'\xe5\x88\x86\xe6\x9c\x9f\xe4\xb8\xad'), (4, b'\xe5\x88\x86\xe6\x9c\x9f\xe5\xb0\xbe\xe6\xac\xbe')], default=1, verbose_name=b'\xe7\xbc\xb4\xe8\xb4\xb9\xe7\xb1\xbb\xe5\x9e\x8b')),
                ('is_checked', models.BooleanField(default=False, verbose_name=b'\xe5\xae\xa1\xe6\xa0\xb8')),
                ('checked_at', models.DateTimeField(null=True)),
                ('after_checked_at', models.DateTimeField(null=True)),
                ('info', models.TextField(blank=True, null=True)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('checked_by', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
                ('preuser', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bee_django_crm.PreUser')),
            ],
            options={
                'ordering': ['-paid_at', '-created_at'],
                'db_table': 'bee_django_crm_preuser_fee',
                'permissions': (('view_crm_preuser_fee', '\u53ef\u4ee5\u67e5\u770b\u7528\u6237\u7f34\u8d39'),),
            },
        ),
        migrations.AlterModelOptions(
            name='preusercontract',
            options={'ordering': ['-created_at'], 'permissions': (('view_crm_preuser_contract', '\u53ef\u4ee5\u67e5\u770b\u7528\u6237\u5408\u540c'),)},
        ),
        migrations.AddField(
            model_name='contract',
            name='agreement',
            field=models.TextField(null=True, verbose_name=b'\xe9\xa1\xbb\xe7\x9f\xa5'),
        ),
        migrations.AddField(
            model_name='preusercontract',
            name='is_migrate',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='preusercontract',
            name='is_user_agree',
            field=models.BooleanField(default=False, verbose_name=b'\xe7\x94\xa8\xe6\x88\xb7\xe6\x98\xaf\xe5\x90\xa6\xe5\x90\x8c\xe6\x84\x8f'),
        ),
        migrations.AlterField(
            model_name='preusercontract',
            name='paid_at',
            field=models.DateTimeField(null=True, verbose_name=b'\xe7\xbc\xb4\xe8\xb4\xb9\xe6\x97\xa5\xe6\x9c\x9f'),
        ),
        migrations.AlterField(
            model_name='preusercontract',
            name='price',
            field=models.FloatField(verbose_name=b'\xe5\xba\x94\xe6\x94\xb6\xe9\x87\x91\xe9\xa2\x9d'),
        ),
        migrations.AddField(
            model_name='preuserfee',
            name='preuser_contract',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bee_django_crm.PreUserContract'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-08-23 10:51
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0009_applicationquestion_is_required'),
    ]

    operations = [
        migrations.AlterField(
            model_name='applicationquestion',
            name='is_required',
            field=models.BooleanField(default=False, help_text=b'\xe5\x8f\xaa\xe5\xaf\xb9\xe8\xbe\x93\xe5\x85\xa5\xe6\xa1\x86\xe5\x92\x8c\xe5\x8d\x95\xe9\x80\x89\xe6\x9c\x89\xe6\x95\x88', verbose_name=b'\xe6\x98\xaf\xe5\x90\xa6\xe5\xbf\x85\xe5\xa1\xab'),
        ),
    ]



#!/usr/bin/env python
# -*- coding:utf-8 -*-
__author__ = 'zhangyue'

from datetime import datetime
from django import template
from bee_django_crm.utils import change_tz, LOCAL_TIMEZONE, get_referral_user_name_with_preuser, get_track_list, \
    get_user_name
from bee_django_crm.utils import get_after_check_url as utils_get_after_check_url
from bee_django_crm.models import APPLICATION_QUESTION_INPUT_TYPE_CHOICES
from bee_django_crm.exports import filter_local_datetime

register = template.Library()


# 获取转介人姓名
@register.filter
def get_referral_user_name(preuser, t=1):
    if t == 1:
        referral_user = preuser.referral_user1
    elif t == 2:
        referral_user = preuser.referral_user2
    else:
        referral_user = None
    if not referral_user:
        return None
    return get_user_name(referral_user)


# 获取联络次数
@register.filter
def get_preuser_track_list(preuser_id):
    return get_track_list(preuser_id)


# 获取自定义user的自定义name
@register.filter
def get_checked_user_name(user):
    return get_user_name(user)


# 本地化时间
@register.filter
def local_datetime(_datetime):
    return filter_local_datetime(_datetime)


# 求两个值的差的绝对值
@register.filter
def get_difference_abs(a, b):
    return abs(a - b)


# 返回option的html
@register.filter("get_html")
def get_html(application, id):
    if not application:
        return ""
    html = "<div>"
    question = application["question"]
    is_required = question.is_required
    required_html = ''
    required_str = ''
    if is_required:
        required_html = 'required'
        required_str = u"<span style='color:red'> ( 必填 ) </span>"
    question_name = question.name
    html += "<div>" + id.__str__() + " . " + question_name + required_str + "</div>"
    options = application["options"]

    # 输入框
    if question.input_type == APPLICATION_QUESTION_INPUT_TYPE_CHOICES[0][0]:
        html += "<div><input type='text' name='input_" + id.__str__() + "'" + required_html + " ></div>"
    # 单选圆钮
    elif question.input_type == APPLICATION_QUESTION_INPUT_TYPE_CHOICES[1][0]:
        for option in options:
            html += "<input type='radio' name='input_" + id.__str__() + "' value='" + option.name + "'" + required_html + " > " + option.name + " "
    # 单选下拉
    elif question.input_type == APPLICATION_QUESTION_INPUT_TYPE_CHOICES[2][0]:
        html += "<select name='input_" + id.__str__() + "'>"
        for option in options:
            html += "<option  value='" + option.name + "'>" + option.name + "</option>"
        html += "</select>"
    # 多选方钮
    elif question.input_type == APPLICATION_QUESTION_INPUT_TYPE_CHOICES[3][0]:
        for option in options:
            html += "<input type='checkbox' name='input_" + id.__str__() + "' value='" + option.name + "' bee_required=" + required_html + "> " + option.name + "<br>"
    html += "</div>"
    return html


# 获取审核后的后续操作的链接
@register.filter("get_after_check_url")
def get_after_check_url(preuser_fee, user):
    if not user or not preuser_fee:
        return None
    url = utils_get_after_check_url(user, preuser_fee)
    if not url:
        return ""
    return "<a href=" + url + ">后续操作</a>"

# @register.filter
# def get_preuser_contract_finish_at(preuser_contract):
#     if not preuser_contract.finish_at.year == 2999:
#         return preuser_contract.finish_at
#     else:
#         return '长期'


#!/usr/bin/env python
# -*- coding:utf-8 -*-

import random
from utils import get_now
from .models import Poster, PreUserContract, PreUserFee
from .signals import fee_checked

__author__ = 'zhangyue'


# 获取显示的海报<poster_id>列表
# 生成的海报路径为：/<CRM_POSTER_PHOTO_PATH>/<poster_id>/<user_id>_poster.jpg
def get_poster_show_list():
    posters = Poster.objects.filter(is_show=True)
    show_list = []
    for poster in posters:
        show_list.append(poster.id)
    return show_list


# 随机获取海报id
def get_random_poster_id():
    posters = get_poster_show_list()
    if len(posters) == 0:
        return None
    poster_id = random.choice(posters)
    return poster_id


# django前台显示本地时间
def filter_local_datetime(_datetime):
    return _datetime


# 费用审核后续操作
def after_check_callback(preuser_fee_id, user=None, new_user=False):
    try:
        preuser_fee = PreUserFee.objects.get(id=preuser_fee_id)
        preuser_fee.after_checked_at = get_now()
        preuser_fee.save()
        # 审核后发送信号
        fee_checked.send(sender=PreUserContract, preuser_fee=preuser_fee, user=user, new_user=new_user)
        return True, None
    except Exception as e:
        return False, e.__str__()


# 获取合同的天数
# return month/week,<时长>
def get_peruser_contract_days(preuser_contract_id):
    try:
        peruser_contract = PreUserContract.objects.get(id=preuser_contract_id)
        contract = peruser_contract.contract
        return contract.period, contract.duration
    except:
        return None, None


# 获取合同的开始日期
# 弃用
def get_peruser_contract_start_day(preuser_contract_id):
    try:
        peruser_contract = PreUserContract.objects.get(id=preuser_contract_id)
        return peruser_contract.study_at
    except:
        return None


# 获取合同的开始日期和结束日期
def get_peruser_contract_start_finish_date(preuser_contract_id):
    try:
        peruser_contract = PreUserContract.objects.get(id=preuser_contract_id)
        return peruser_contract.study_at, peruser_contract.finish_at
    except:
        return None, None


# 获取缴费时的开始日期，及付款方式
# return month/week,<时长>
# 弃用
def get_peruser_fee_start_day(preuser_fee_id):
    try:
        peruser_fee = PreUserFee.objects.get(id=preuser_fee_id)
        return peruser_fee.study_at, peruser_fee.pay_status
    except:
        return None
